@@ -947,6 +947,198 @@ class ChangingPassPhraseAPI(APIBaseClass):
         else:
             raise RequestError(self.error)
 
+class PostageRatesAPI(APIBaseClass):
+    """
+    Calculate the Postage and Fees for a multiple mailclass
+    """
+    def __init__(self,
+                 mailclass,
+                 weightoz,
+                 from_postal_code,
+                 to_postal_code,
+                 to_country_code,
+                 **kwargs):
+        '''
+
+        :param requesterid: (Text, 50) : Requester ID (also called Partner ID) is used to uniquely identify the system making the request. This ID is assigned by Endicia.
+
+        :param mailclass: (Text): Domestic/International
+
+        :param weightoz: (Numeric, 4.1) : Weight of the package, in ounces.
+
+        :param from_postal_code: (Text, 5) : Sender's postal code. The format is ZIP5. For Parcel Select and Standard Mail, the value of this element contains the zip code of the postal facility specified in EntryFacility. Recipient's postal code.
+
+        :param to_postal_code: (Text)
+
+            * 5: For Domestic Mail, the format is ZIP5 (required).
+            * 15: For International Mail (optional).
+
+        :param to_country_code: (Text, 2) : Two character country code of the recipient's country. Required for International Mail. Use either ToCountry or ToCountryCode.
+
+        All the elements mentioned hereafter are sent to the API by using add_data() method.
+        =====================================================================================
+        Example ::
+                shipping_label_api.add_data(
+                                    {
+                        'Pricing': 'CommercialBase'
+                                    }
+                        )
+
+        :param CertifiedIntermediary: (Node) : Certified Intermediary (CI) account authentication information.
+            * AccountID: (Numeric, 6) : Account ID for the Endicia postage account.
+            * PassPhrase: (Text, 64) : Pass Phrase for the Endicia postage account.
+
+        :param Pricing: (Text)
+
+            * CommercialBase : Commercial Base pricing.
+            * CommercialPlus : Commercial Plus pricing.
+            * Retail : Retail pricing.
+
+            If this element is not supplied, pricing will be based on the MailClass and any qualified discounts available to AccountID.
+
+            .. note::
+                If this element is set to CommercialPlus, but the account does not qualify for such pricing, the Web method will return an error.
+
+        :param MailpieceShape: (Text) : Card / Letter / Flat / Parcel / LargeParcel / IrregularParcel / OversizedParcel / FlatRateEnvelope / FlatRatePaddedEnvelope / SmallFlatRateBox / MediumFlatRateBox / LargeFlatRateBox
+
+            * Shape of the mailpiece.
+            * Starting in May 2009, FlatRateBox has been replaced with MediumFlatRateBox.
+            * The Flat Rate Padded Envelope is only available to qualifying Priority Mail Commercial Plus customers. The Label Server will return an error if this shape is used with any other pricing.
+
+        :param MailpieceDimensions: (Node):  Dimensions of the mailpiece. Required for calculating Cubic pricing and for Priority Mail mailpieces going to Zones 5-8 which are over 1 cubic foot. Ignored if MailpieceShape is set to either LargeParcel or OversizedParcel. **All values must be in inches.**
+
+            * Length (Numeric, 3.3) : Length of the mailpiece.
+            * Width (Numeric, 3.3) : Width of the mailpiece.
+            * Height (Numeric, 3.3) : Height (or thickness) of the mailpiece.
+
+        :param Machinable: (Text)
+
+            * TRUE : Package is machinable. (Default) Package is non-machinable.
+            * FALSE : If a Parcel Select mailpiece marked as machinable is over 35 lbs. in weight or its MailpieceShape is set to OversizedParcel, it will automatically be charged the non- machinable rate.
+
+        :param Services: (Node) : Special Services requested for the package.
+
+            * CertifiedMail (Attribute)
+
+                * OFF : Certified Mail not requested.
+                * ON : Certified Mail requested.
+
+            * COD (Attribute)
+
+                * OFF : COD not requested.
+                * ON : COD requested.
+
+            * DeliveryConfirmation (Attribute)
+
+                * OFF : Delivery Confirmation not requested. (Default)
+                * ON : Delivery Confirmation requested.
+
+            * ElectronicReturnReceipt (Attribute)
+
+                * OFF : Electronic Return Receipt not requested. (Default)
+                * ON : Electronic Return Receipt requested.
+
+             * InsuredMail (Attribute)
+
+                * OFF : No insurance requested. (Default)
+                * ON : USPS Insurance requested.
+                * UspsOnline : USPS Online Insurance requested.
+                * ENDICIA : Endicia Insurance requested (Maximum insurable value: $10,000)
+
+                .. note::
+                    * USPS Online Insurance is available only for mailpieces with Delivery or Signature Confirmation.
+                    * USPS Insurance is not allowed for International Mail.
+                    * Endicia insurance fee is not included in the postage price. It is billed to your account.
+
+            * RestrictedDelivery (Attribute)
+
+                * OFF : Restricted Delivery not requested.(Default)
+                * ON : Restricted Delivery requested.
+
+            * ReturnReceipt (Attribute)
+
+                * OFF : Return Receipt not requested.(Default)
+                * ON : Return Receipt requested.
+
+            * SignatureConfirmation (Attribute)
+
+                * OFF : Signature Confirmation not requested. (Default)
+                * ON : Signature Confirmation requested.
+
+        :param CODAmount: (Currency, 5.2) : COD amount to collect. Required if COD is requested for the mailpiece.
+        :param InsuredValue: (Currency, 5.2) : Insured value of the mailpiece. Required if insurance or COD is requested for the mailpiece.
+        :param ToCountryCode: (Text, 2) : Recipient's country code. Required for International Mail. Use either ToCountryCode.
+        '''
+        super(PostageRatesAPI, self).__init__(**kwargs)
+
+        self.mailclass = mailclass
+        self.weightoz = weightoz
+        self.frompostalcode = from_postal_code
+        self.topostalcode = to_postal_code
+        self.tocountrycode = to_country_code
+        self.valid_elements.extend([
+            'RequesterID',
+            'MailClass',
+            'Pricing',
+            'WeightOz',
+            'MailpieceShape',
+            'MailpieceDimensions',
+            'AutomationRate',
+            'Machinable',
+            'ServiceLevel',
+            'SundayHolidayDelivery',
+            'SortType',
+            'Services',
+            'Value',
+            'CODAmount',
+            'InsuredValue',
+            'EntryFacility',
+            'FromPostalCode',
+            'ToPostalCode',
+            'ToCountry',
+            'ToCountryCode',
+            'ShipDate',
+            'ShipTime'
+        ])
+        self.namespace = '{' + self.base_namespace + 'LabelService}'
+        self.url = self.base_url + \
+            "LabelService/EwsLabelService.asmx/CalculatePostageRatesXML"
+
+    def to_xml(self, as_string=True):
+        """
+        Convert the data To xml
+        """
+        postageratesrequest = etree.Element("PostageRatesRequest")
+
+        transform_to_xml(postageratesrequest,
+                         self.requesterid, 'RequesterID')
+        transform_to_xml(postageratesrequest, [
+            Element('AccountID', self.accountid),
+            Element('PassPhrase', self.passphrase),
+        ], 'CertifiedIntermediary')
+
+        for element in self.valid_elements:
+            if not hasattr(self, element.lower()):
+                # If element is not there then bypass it
+                continue
+            value = getattr(self, element.lower())
+            transform_to_xml(postageratesrequest, value, element)
+
+        if as_string:
+            return etree.tostring(postageratesrequest, pretty_print=True)
+        else:
+            return postageratesrequest
+
+    def send_request(self):
+        """
+        Sends the request to the server
+        """
+        response = self.request({'postageRatesRequestXML': self.to_xml()})
+        if self.success:
+            return response
+        else:
+            raise RequestError(self.error)
+
 
 class CalculatingPostageAPI(APIBaseClass):
     """
